@@ -135,7 +135,7 @@ class ComponentVisitor(BaseVisitor):
         # Since the definition is named, register it with the namespace
         self.compiler.namespace.register_type(def_name, comp_def, src_ref_from_antlr(ctx.ID()))
 
-        # A named component's scope name is the same as it's type name
+        # A named component's scope name is the same as its type name
         comp_def._scope_name = def_name
 
         return comp_def
@@ -512,7 +512,7 @@ class ComponentVisitor(BaseVisitor):
         param_data_type = self.datatype_from_token(data_type_token)
         if ctx.array_type_suffix() is None:
             # Non-array type
-            param_type = param_data_type # type: Union[Type[Union[int, str, bool, rdltypes.BuiltinEnum, rdltypes.UserEnum, rdltypes.UserStruct, rdltypes.references.RefType]], rdltypes.ArrayPlaceholder]
+            param_type = param_data_type # type: Union[Type[Union[int, str, bool, rdltypes.BuiltinEnum, rdltypes.UserEnum, rdltypes.UserStruct, rdltypes.references.RefType, comp.Component]], rdltypes.ArrayPlaceholder]
         else:
             # Array-like type
             param_type = rdltypes.ArrayPlaceholder(param_data_type)
