@@ -180,7 +180,7 @@ class ValidateListener(walker.RDLListener):
             if node.array_stride > (node.get_property('regwidth') // 8):
                 self.msg.message(
                     self.env.chk_sparse_reg_stride,
-                    "Address stride (+= %d) of register array '%s' is not equal to it's width (regwidth/8 = %d)"
+                    "Address stride (+= %d) of register array '%s' is not equal to its width (regwidth/8 = %d)"
                     % (node.array_stride, node.inst_name, (node.get_property('regwidth') // 8)),
                     node.inst.inst_src_ref
                 )
@@ -398,7 +398,7 @@ class ValidateListener(walker.RDLListener):
         # Optional warning if a field is missing a reset assignment
         if node.env.chk_missing_reset:
             # Implements storage but was never assigned a reset
-            if node.implements_storage and (node.get_property('reset') is None):
+            if (not node.is_virtual) and node.implements_storage and (node.get_property('reset') is None):
                 node.env.msg.message(
                     node.env.chk_missing_reset,
                     "Field '%s' implements storage but is missing a reset value. Initial state is undefined"
